/* trapRook.h
 */
#ifndef OSL_MOVE_CLASSIFIER_TRAPROOK_H
#define OSL_MOVE_CLASSIFIER_TRAPROOK_H

#include "osl/state/numEffectState.h"
namespace osl
{
  namespace move_classifier
  {
    /**
     * @param 指す側  alt(P)の飛車を封じ込める(のに結構な確率で貢献する)手かどうか
     */
    template <Player P>
    struct TrapRook
    {
      static bool
#ifdef __GNUC__
	__attribute__ ((pure))
#endif
      isMember(const NumEffectState& state, 
	       Ptype ptype,Square from,Square to);
    private:
      template <Direction Dir>
      static bool
#ifdef __GNUC__
	__attribute__ ((pure))
#endif
      testDirection(const NumEffectState& state, Square initial);
    };
  } // namespace move_classifier
} // namespace osl


#endif /* OSL_MOVE_CLASSIFIER_TRAPROOK_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; coding:utf-8
// ;;; End:
